@@ -6,7 +6,10 @@ from walker.commands.cp import ClipboardCopy, CopyCommandHelper
 from walker.commands.command import Command
 from walker.commands.command_helpers import ClusterCommandHelper, ClusterOrPodCommandHelper, PodCommandHelper
 from walker.commands.cqlsh import CqlCommandHelper, Cqlsh
+from walker.commands.frontend.setup import Setup, SetupCommandHelper
+from walker.commands.frontend.teardown import TearDown, TearDownCommandHelper
 from walker.commands.issues import Issues
+from walker.commands.login import Login
 from walker.commands.logs import Logs
 from walker.commands.ls import Ls
 from walker.commands.medusa.medusa import Medusa
@@ -22,6 +25,7 @@ from walker.commands.rollout import RollOut
 from walker.commands.show.show import Show, ShowCommandHelper
 from walker.commands.status import Status as StatusCmd
 from walker.commands.storage import Storage
+from walker.commands.user_entry import UserEntry
 from walker.commands.watch import Watch
 from walker.k8s_utils.kube_context import KubeContext
 from walker.repl import enter_repl
@@ -89,6 +93,17 @@ def issues(kubeconfig: str, config: str, param: list[str], cluster: str, namespa
     run_command(Issues(), kubeconfig, config, param, cluster, namespace, pod, ('-s',) + extra_args if show else extra_args)
 
 
+@cli.command(context_settings=dict(ignore_unknown_options=True, allow_extra_args=True), cls=PodCommandHelper, help='Get cassandra log.')
+@click.option('--kubeconfig', '-k', required=False, metavar='path', help='path to kubeconfig file')
+@click.option('--config', default='params.yaml', metavar='path', help='path to kaqing parameters file')
+@click.option('--param', '-v', multiple=True, metavar='<key>=<value>', help='parameter override')
+@click.option('--namespace', '-n', required=False, metavar='namespace', help='Kubernetes namespace')
+@click.option('--pod', '-p', required=False, metavar='pod', help='Kubernetes pod name')
+@click.argument('extra_args', nargs=-1, metavar='<pod>', type=click.UNPROCESSED)
+def login(kubeconfig: str, config: str, param: list[str], namespace: str, pod: str, extra_args):
+    run_command(Login(), kubeconfig, config, param, None, namespace, pod, extra_args)
+
+
 @cli.command(context_settings=dict(ignore_unknown_options=True, allow_extra_args=True), cls=PodCommandHelper, help='Get cassandra log.')
 @click.option('--kubeconfig', '-k', required=False, metavar='path', help='path to kubeconfig file')
 @click.option('--config', default='params.yaml', metavar='path', help='path to kaqing parameters file')
@@ -230,6 +245,16 @@ def rollout(kubeconfig: str, config: str, param: list[str], cluster: str, namesp
     run_command(RollOut(), kubeconfig, config, param, cluster, namespace, None, extra_args)
 
 
+@cli.command(context_settings=dict(ignore_unknown_options=True, allow_extra_args=True), cls=SetupCommandHelper, help='Setup.')
+@click.option('--kubeconfig', '-k', required=False, metavar='path', help='path to kubeconfig file')
+@click.option('--config', default='params.yaml', metavar='path', help='path to kaqing parameters file')
+@click.option('--param', '-v', multiple=True, metavar='<key>=<value>', help='parameter override')
+@click.option('--namespace', '-n', required=False, metavar='namespace', help='Kubernetes namespace')
+@click.argument('extra_args', nargs=-1, metavar='<pod>', type=click.UNPROCESSED)
+def setup(kubeconfig: str, config: str, param: list[str], namespace: str, extra_args):
+    run_command(Setup(), kubeconfig, config, param, None, namespace, None, extra_args)
+
+
 @cli.command(context_settings=dict(ignore_unknown_options=True, allow_extra_args=True), cls=ShowCommandHelper, help='Show configuration or kubectl commands.')
 @click.option('--kubeconfig', '-k', required=False, metavar='path', help='path to kubeconfig file')
 @click.option('--config', default='params.yaml', metavar='path', help='path to kaqing parameters file')
@@ -268,6 +293,26 @@ def storage(kubeconfig: str, config: str, param: list[str], cluster: str, namesp
     run_command(Storage(), kubeconfig, config, param, cluster, namespace, pod, ('-s',) + extra_args if show else extra_args)
 
 
+@cli.command(context_settings=dict(ignore_unknown_options=True, allow_extra_args=True), cls=TearDownCommandHelper, help='Teardown.')
+@click.option('--kubeconfig', '-k', required=False, metavar='path', help='path to kubeconfig file')
+@click.option('--config', default='params.yaml', metavar='path', help='path to kaqing parameters file')
+@click.option('--param', '-v', multiple=True, metavar='<key>=<value>', help='parameter override')
+@click.option('--namespace', '-n', required=False, metavar='namespace', help='Kubernetes namespace')
+@click.argument('extra_args', nargs=-1, metavar='<pod>', type=click.UNPROCESSED)
+def teardown(kubeconfig: str, config: str, param: list[str], namespace: str, extra_args):
+    run_command(TearDown(), kubeconfig, config, param, None, namespace, None, extra_args)
+
+
+@cli.command(context_settings=dict(ignore_unknown_options=True, allow_extra_args=True), cls=PodCommandHelper, help='Get cassandra log.')
+@click.option('--kubeconfig', '-k', required=False, metavar='path', help='path to kubeconfig file')
+@click.option('--config', default='params.yaml', metavar='path', help='path to kaqing parameters file')
+@click.option('--param', '-v', multiple=True, metavar='<key>=<value>', help='parameter override')
+@click.option('--namespace', '-n', required=False, metavar='namespace', help='Kubernetes namespace')
+@click.argument('extra_args', nargs=-1, metavar='<pod>', type=click.UNPROCESSED)
+def entry(kubeconfig: str, config: str, param: list[str], namespace: str, extra_args):
+    run_command(UserEntry(), kubeconfig, config, param, None, namespace, None, extra_args)
+
+
 @cli.command(context_settings=dict(ignore_unknown_options=True, allow_extra_args=True), cls=ClusterOrPodCommandHelper, help='Watch pods in cluster.')
 @click.option('--kubeconfig', '-k', required=False, metavar='path', help='path to kubeconfig file')
 @click.option('--config', default='params.yaml', metavar='path', help='path to kaqing parameters file')
